import { Draft } from 'immer';
import { MatrixGenerationOptions } from 'nmr-load-save';
import { MatrixOptions } from '../../../../data/types/data1d/MatrixOptions';
import { ZoomOptions } from '../../../EventsTrackers/BrushTracker';
import { FilterType } from '../../../utility/filterType';
import { ActionType } from '../../types/ActionType';
import { PreferencesState } from '../preferencesReducer';
type setMatrixGenerationOptionsAction = ActionType<'SET_MATRIX_GENERATION_OPTIONS', {
    nucleus: string;
    options: MatrixOptions;
}>;
type addMatrixGenerationExclusionZoneAction = ActionType<'ADD_MATRIX_GENERATION_EXCLUSION_ZONE', {
    zone: {
        from: number;
        to: number;
    };
    range: {
        from: number;
        to: number;
    };
    nucleus: string;
}>;
type deleteMatrixGenerationExclusionZoneAction = ActionType<'DELETE_MATRIX_GENERATION_EXCLUSION_ZONE', {
    zone: {
        id: string;
        from: number;
        to: number;
    };
    nucleus: string;
}>;
type ToggleMatrixGenerationViewAction = ActionType<'TOGGLE_MATRIX_GENERATION_VIEW_PROPERTY', {
    key: keyof FilterType<MatrixGenerationOptions, boolean>;
    nucleus: string;
}>;
type ChangeMatrixGenerationScaleAction = ActionType<'CHANGE_MATRIX_GENERATION_SCALE', {
    zoomOptions: ZoomOptions;
    nucleus: string;
}>;
type ChangeMatrixGenerationStocsyChemicalShiftAction = ActionType<'CHANGE_MATRIX_GENERATION_STOCSY_CHEMICAL_SHIFT', {
    nucleus: string;
    chemicalShift: number;
}>;
export type MatrixGenerationActions = ToggleMatrixGenerationViewAction | deleteMatrixGenerationExclusionZoneAction | addMatrixGenerationExclusionZoneAction | setMatrixGenerationOptionsAction | ChangeMatrixGenerationScaleAction | ChangeMatrixGenerationStocsyChemicalShiftAction;
declare function addExclusionZone(draft: Draft<PreferencesState>, action: addMatrixGenerationExclusionZoneAction): void;
declare function deleteExclusionZone(draft: Draft<PreferencesState>, action: any): void;
declare function setMatrixGenerationOptions(draft: Draft<PreferencesState>, action: any): void;
declare function toggleMatrixGenerationViewProperty(draft: Draft<PreferencesState>, action: ToggleMatrixGenerationViewAction): void;
declare function resetDefaultViewMatrixGenerationOptions(draft: Draft<PreferencesState>, action: ToggleMatrixGenerationViewAction): void;
declare function changeMatrixGenerationScale(draft: Draft<PreferencesState>, action: ChangeMatrixGenerationScaleAction): void;
declare function changeMatrixGenerationStocsyChemicalShift(draft: Draft<PreferencesState>, action: ChangeMatrixGenerationStocsyChemicalShiftAction): null | undefined;
export { addExclusionZone, deleteExclusionZone, setMatrixGenerationOptions, toggleMatrixGenerationViewProperty, changeMatrixGenerationScale, changeMatrixGenerationStocsyChemicalShift, resetDefaultViewMatrixGenerationOptions, };
